<?php

namespace App\Admin\Controllers;

use App\Models\Category;
use Dcat\Admin\Form;
use Dcat\Admin\Grid;
use Dcat\Admin\Show;
use Dcat\Admin\Layout\Content;
use Dcat\Admin\Layout\Row;
use Dcat\Admin\Tree;
use Dcat\Admin\Http\Controllers\AdminController;
use NwVVVS\AdapaySdk\AdapayTools;

class CategoryControllerTest extends AdminController
{

    public function index(Content $content)
    {
        return $content->header('对账单下载')
            ->description('csv')
            ->body(function (Row $row) {
                // 移除表单创建逻辑
                // 这里可以添加你想要展示的内容，例如文本信息---
                //$row->column(12, '<p>这是对账单下载页面，请选择合适的操作。</p>');
                // 添加时间选择控件和按钮
                $row->column(12, '<input type="date" id="download-date" />');
                $row->column(12, '<button id="download-button">下载</button>');

                // 添加 JavaScript 代码绑定点击事件
                $row->column(
                    12,
                    <<<HTML
                                <script>
                                document.getElementById('download-button').addEventListener('click', function() {
                                    var date = document.getElementById('download-date').value;
                                    if (date) {
                                        fetch('/category-download?date=' + date, {
                                            method: 'GET'
                                        })
                                    .then(response => response.json())
                                    .then(data => {
                                            console.log(data);
                                            // 这里可以添加更多处理逻辑，例如显示提示信息
                                        });
                                    } else {
                                        alert('请选择日期');
                                    }
                                });
                                </script>
                                HTML
                );
            });
    }

    /**
     * 处理下载请求
     */
    public function download()
    {
        $date = request()->input('date');

        # 初始化对账单下载对象类
        $bill = new AdapayTools;

        # 对账单日期

        # 对账单下载
        $bill->download(["bill_date" => "20250303"]);

        # 对账单下载结果进行处理
        if ($bill->isError()) {
            //失败处理
            //var_dump($bill->result);
        } else {
            //成功处理
            //var_dump($bill->result);
        }


        return response()->json(['message' => '下载请求已接收', 'date' => $bill]);
    }

    /**
     * Make a grid builder.
     *
     * @return Grid
     */
    protected function grid()
    {
        return Grid::make(new Category(), function (Grid $grid) {
            $grid->column('id')->sortable();
            $grid->column('parent_id');
            $grid->column('title');
            $grid->column('icon');
            $grid->column('order');
            $grid->column('show');
            $grid->column('created_at');
            $grid->column('updated_at')->sortable();

            $grid->filter(function (Grid\Filter $filter) {
                $filter->equal('id');
            });

            // 隐藏列表操作按钮
            $grid->disableActions();

            // 隐藏列表顶部的按钮
            $grid->disableCreateButton();
            $grid->disableBatchDelete();
            $grid->disableExport();
            $grid->disableFilterButton();
        });
    }

    /**
     * Make a show builder.
     *
     * @param mixed $id
     *
     * @return Show
     */
    protected function detail($id)
    {
        return Show::make($id, new Category(), function (Show $show) {
            $show->field('id');
            $show->field('parent_id');
            $show->field('title');
            $show->field('icon');
            $show->field('order');
            $show->field('show');
            $show->field('created_at');
            $show->field('updated_at');
        });
    }

    /**
     * Make a form builder.
     *
     * @return Form
     */
    protected function form()
    {
        return Form::make(new Category(), function (Form $form) {
            $form->display('id');
            $form->select('parent_id')
                ->options(Category::selectOptions())
                ->saving(function ($v) {
                    return $v ?? 0;
                });
            $form->text('title');
            // $form->image('icon', '分类图标')
            //     ->accept('jpg,jpeg,png')
            //     ->maxSize(4096)
            //     ->url('upload/category')
            //     ->help('仅支持jpg、jpeg、png格式图片上传（750px * 420px）')
            //     ->autoUpload();
            $form->text('order')->help('越小越靠前');
            $form->switch('show', '状态')->default(1);

            // $form->display('created_at');
            // $form->display('updated_at');

            // 隐藏表单底部的按钮
            $form->disableResetButton();
            $form->disableViewCheck();
            $form->disableEditingCheck();
            $form->disableCreatingCheck();

            // 如果你想隐藏提交按钮，可以使用以下代码
            // $form->disableSubmit();
        });
    }
}
